SoMeWeTa
========

SoMeWeTa is a state-of-the-art part-of-speech tagger for German web
and social media texts that follows the guidelines of the `EmpiriST
2015 shared task <https://sites.google.com/site/empirist2015/>`_ on
automatic linguistic annotation of computer-mediated communication /
social media. SoMeWeTa is particularly well-suited to tag all kinds of
written discourse, for example chats, forums, wiki talk pages, tweets,
blog comments, social networks, SMS and WhatsApp dialogues.

More detailed documentation is available `here
<https://github.com/tsproisl/SoMeWeTa>`_.
